==> kafka-streams-6.0.5-ccs-test-sources.jar: org/apache/kafka/test/MockProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.test;

import org.apache.kafka.streams.KeyValueTimestamp;
import org.apache.kafka.streams.processor.AbstractProcessor;
import org.apache.kafka.streams.processor.Cancellable;
import org.apache.kafka.streams.processor.ProcessorContext;
import org.apache.kafka.streams.processor.PunctuationType;
import org.apache.kafka.streams.state.ValueAndTimestamp;

import java.time.Duration;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import static org.junit.Assert.assertEquals;

public class MockProcessor<K, V> extends AbstractProcessor<K, V> {

    public final ArrayList<KeyValueTimestamp<Object, Object>> processed = new ArrayList<>();
    public final Map<K, ValueAndTimestamp<V>> lastValueAndTimestampPerKey = new HashMap<>();

    public final ArrayList<Long> punctuatedStreamTime = new ArrayList<>();
    public final ArrayList<Long> punctuatedSystemTime = new ArrayList<>();

    public Cancellable scheduleCancellable;

    private final PunctuationType punctuationType;
    private final long scheduleInterval;

    private boolean commitRequested = false;

    public MockProcessor(final PunctuationType punctuationType,
                         final long scheduleInterval) {
        this.punctuationType = punctuationType;
        this.scheduleInterval = scheduleInterval;
    }

    public MockProcessor() {
        this(PunctuationType.STREAM_TIME, -1);
    }

    @Override
    public void init(final ProcessorContext context) {
        super.init(context);
        if (scheduleInterval > 0L) {
            scheduleCancellable = context.schedule(
                Duration.ofMillis(scheduleInterval),
                punctuationType,
                timestamp -> {
                    if (punctuationType == PunctuationType.STREAM_TIME) {
                        assertEquals(timestamp, context().timestamp());
                    }
                    assertEquals(-1, context().partition());
                    assertEquals(-1L, context().offset());

                    (punctuationType == PunctuationType.STREAM_TIME ? punctuatedStreamTime : punctuatedSystemTime)
                            .add(timestamp);
                });
        }
    }

    @Override
    public void process(final K key, final V value) {
        KeyValueTimestamp<Object, Object> keyValueTimestamp = new KeyValueTimestamp<>(key, value, context().timestamp());

        if (value != null) {
            lastValueAndTimestampPerKey.put(key, ValueAndTimestamp.make(value, context().timestamp()));
        } else {
            lastValueAndTimestampPerKey.remove(key);
        }

        processed.add(keyValueTimestamp);

        if (commitRequested) {
            context().commit();
            commitRequested = false;
        }
    }

    public void checkAndClearProcessResult(final KeyValueTimestamp<?, ?>... expected) {
        assertEquals("the number of outputs:" + processed, expected.length, processed.size());
        for (int i = 0; i < expected.length; i++) {
            assertEquals("output[" + i + "]:", expected[i], processed.get(i));
        }

        processed.clear();
    }

    public void requestCommit() {
        commitRequested = true;
    }

    public void checkEmptyAndClearProcessResult() {
        assertEquals("the number of outputs:", 0, processed.size());
        processed.clear();
    }

    public void checkAndClearPunctuateResult(final PunctuationType type, final long... expected) {
        final ArrayList<Long> punctuated = type == PunctuationType.STREAM_TIME ? punctuatedStreamTime : punctuatedSystemTime;
        assertEquals("the number of outputs:", expected.length, punctuated.size());

        for (int i = 0; i < expected.length; i++) {
            assertEquals("output[" + i + "]:", expected[i], (long) punctuated.get(i));
        }

        processed.clear();
    }
}

==> kafka-streams-6.1.3-ccs-test-sources.jar: org/apache/kafka/test/MockProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.test;

import org.apache.kafka.streams.KeyValueTimestamp;
import org.apache.kafka.streams.processor.AbstractProcessor;
import org.apache.kafka.streams.processor.Cancellable;
import org.apache.kafka.streams.processor.ProcessorContext;
import org.apache.kafka.streams.processor.PunctuationType;
import org.apache.kafka.streams.processor.api.Record;
import org.apache.kafka.streams.state.ValueAndTimestamp;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class MockProcessor<K, V> extends AbstractProcessor<K, V> {
    private final MockApiProcessor<K, V, Object, Object> delegate;

    public MockProcessor(final PunctuationType punctuationType,
                         final long scheduleInterval) {
        delegate = new MockApiProcessor<>(punctuationType, scheduleInterval);
    }

    public MockProcessor() {
        delegate = new MockApiProcessor<>();
    }

    @SuppressWarnings("unchecked")
    @Override
    public void init(final ProcessorContext context) {
        super.init(context);
        delegate.init((org.apache.kafka.streams.processor.api.ProcessorContext<Object, Object>) context);
    }

    @Override
    public void process(final K key, final V value) {
        delegate.process(new Record<>(key, value, context.timestamp(), context.headers()));
    }

    public void checkAndClearProcessResult(final KeyValueTimestamp<?, ?>... expected) {
        delegate.checkAndClearProcessResult(expected);
    }

    public void requestCommit() {
        delegate.requestCommit();
    }

    public void checkEmptyAndClearProcessResult() {
        delegate.checkEmptyAndClearProcessResult();
    }

    public void checkAndClearPunctuateResult(final PunctuationType type, final long... expected) {
        delegate.checkAndClearPunctuateResult(type, expected);
    }

    public Map<K, ValueAndTimestamp<V>> lastValueAndTimestampPerKey() {
        return delegate.lastValueAndTimestampPerKey();
    }

    public List<Long> punctuatedStreamTime() {
        return delegate.punctuatedStreamTime();
    }

    public Cancellable scheduleCancellable() {
        return delegate.scheduleCancellable();
    }

    public ArrayList<KeyValueTimestamp<K, V>> processed() {
        return delegate.processed();
    }
}
